@@ -4,9 +4,8 @@
 package term
 
 import (
-	"os"
-
 	"github.com/lmorg/murex/lang/stdio"
+	"github.com/lmorg/murex/lang/tty"
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/ansi/codes"
 )
@@ -27,9 +26,9 @@ func (t *ErrRed) Write(b []byte) (i int, err error) {
 	t.bWritten += uint64(len(b))
 	t.mutex.Unlock()
 
-	i, err = os.Stderr.WriteString(codes.FgRed + string(b) + codes.Reset)
+	i, err = tty.Stderr.WriteString(codes.FgRed + string(b) + codes.Reset)
 	if err != nil {
-		os.Stdout.WriteString(codes.FgRed + err.Error() + codes.Reset)
+		tty.Stdout.WriteString(codes.FgRed + err.Error() + codes.Reset)
 	}
 
 	return i - 9, err
