@@ -1,7 +1,6 @@
 package expressions
 
 import (
-	"encoding/json"
 	"fmt"
 	"reflect"
 	"strings"
@@ -30,40 +29,84 @@ func convertScalarToBareword(node *astNodeT) {
 	}
 }
 
-func expAssign(tree *ParserT) error {
-	left, right, err := tree.getLeftAndRightSymbols()
+func expAssign(tree *ParserT, overwriteType bool) error {
+	leftNode, rightNode, err := tree.getLeftAndRightSymbols()
 	if err != nil {
 		return err
 	}
 
-	convertScalarToBareword(left)
+	convertScalarToBareword(leftNode)
 
-	if left.key != symbols.Bareword {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
+	if leftNode.key != symbols.Bareword {
+		return raiseError(tree.expression, leftNode, 0, fmt.Sprintf(
 			"left side of %s should be a bareword, instead got %s",
-			tree.currentSymbol().key, left.key))
+			tree.currentSymbol().key, leftNode.key))
 	}
 
-	if right.key <= symbols.Bareword {
-		return raiseError(tree.expression, right, 0, fmt.Sprintf(
+	if rightNode.key <= symbols.Bareword {
+		return raiseError(tree.expression, rightNode, 0, fmt.Sprintf(
 			"right side of %s should not be a %s",
-			tree.currentSymbol().key, right.key))
+			tree.currentSymbol().key, rightNode.key))
 	}
 
-	var v interface{}
-	switch right.dt.Primitive {
+	var (
+		v  interface{}
+		dt string
+	)
+
+	right, err := rightNode.dt.GetValue()
+	if err != nil {
+		return err
+	}
+
+	switch right.Primitive {
 	case primitives.Array, primitives.Object:
-		b, err := json.Marshal(right.dt.Value)
-		if err != nil {
-			return err
+		if overwriteType {
+			dt = types.Json
+		} else {
+			dt = tree.p.Variables.GetDataType(leftNode.Value())
+			if dt == "" {
+				dt = types.Json
+			}
+		}
+
+		// this is ugly but Go's JSON marshaller is better behaved than Murexes on with empty values
+		if dt == types.Json {
+			b, err := right.Marshal()
+			if err != nil {
+				raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+			}
+			v = string(b)
+		} else {
+			b, err := lang.MarshalData(tree.p, dt, right.Value)
+			if err != nil {
+				raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+			}
+			v = string(b)
 		}
-		v = string(b)
 
 	default:
-		v = right.dt.Value
+		if overwriteType {
+			dt = right.DataType
+			v = right.Value
+
+		} else {
+			dt = tree.p.Variables.GetDataType(leftNode.Value())
+			if dt == "" || dt == types.Null {
+				dt = right.DataType
+				v = right.Value
+
+			} else {
+
+				v, err = types.ConvertGoType(right.Value, dt)
+				if err != nil {
+					raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+				}
+			}
+		}
 	}
 
-	err = tree.setVar(left.value, v, right.dt.DataType())
+	err = tree.setVar(leftNode.value, v, dt)
 	if err != nil {
 		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
 	}
@@ -71,25 +114,27 @@ func expAssign(tree *ParserT) error {
 	return tree.foldAst(&astNodeT{
 		key: symbols.Calculated,
 		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Null,
-			Value:     nil,
-		},
+		dt:  primitives.NewPrimitive(primitives.Null, nil),
 	})
 }
 
 func expAssignAdd(tree *ParserT) error {
-	left, right, err := tree.getLeftAndRightSymbols()
+	leftNode, rightNode, err := tree.getLeftAndRightSymbols()
 	if err != nil {
 		return err
 	}
 
-	convertScalarToBareword(left)
+	convertScalarToBareword(leftNode)
 
-	if left.key != symbols.Bareword {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
+	right, err := rightNode.dt.GetValue()
+	if err != nil {
+		return err
+	}
+
+	if leftNode.key != symbols.Bareword {
+		return raiseError(tree.expression, leftNode, 0, fmt.Sprintf(
 			"left side of %s should be a bareword, instead got %s",
-			tree.currentSymbol().key, left.key))
+			tree.currentSymbol().key, leftNode.key))
 	}
 
 	/*if right.key != symbols.Number {
@@ -97,7 +142,7 @@ func expAssignAdd(tree *ParserT) error {
 			"right side should not be a %s", right.key))
 	}*/
 
-	v, dt, err := tree.getVar(left.value, varAsValue)
+	v, dt, err := tree.getVar(leftNode.value, varAsValue)
 	if err != nil {
 		if !tree.StrictTypes() && strings.Contains(err.Error(), lang.ErrDoesNotExist) {
 			// var doesn't exist and we have strict types disabled so lets create var
@@ -111,43 +156,43 @@ func expAssignAdd(tree *ParserT) error {
 
 	switch dt {
 	case types.Number, types.Float:
-		if right.dt.Primitive != primitives.Number {
+		if right.Primitive != primitives.Number {
 			return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
-				"cannot %s %s to %s", tree.currentSymbol().key, right.dt.Primitive, dt))
+				"cannot %s %s to %s", tree.currentSymbol().key, right.Primitive, dt))
 		}
-		result = v.(float64) + right.dt.Value.(float64)
+		result = v.(float64) + right.Value.(float64)
 
 	case types.Integer:
-		if right.dt.Primitive != primitives.Number {
+		if right.Primitive != primitives.Number {
 			return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
-				"cannot %s %s to %s", tree.currentSymbol().key, right.dt.Primitive, dt))
+				"cannot %s %s to %s", tree.currentSymbol().key, right.Primitive, dt))
 		}
-		result = float64(v.(int)) + right.dt.Value.(float64)
+		result = float64(v.(int)) + right.Value.(float64)
 
 	case types.Boolean:
 		return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
 			"cannot %s %s", tree.currentSymbol().key, dt))
 
 	case types.Null:
-		switch right.dt.Primitive {
+		switch right.Primitive {
 		case primitives.String:
-			result = right.dt.Value.(string)
+			result = right.Value.(string)
 		case primitives.Number:
-			result = right.dt.Value.(float64)
+			result = right.Value.(float64)
 		default:
 			return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
-				"cannot %s %s to %s", tree.currentSymbol().key, right.dt.Primitive, dt))
+				"cannot %s %s to %s", tree.currentSymbol().key, right.Primitive, dt))
 		}
 
 	default:
-		if right.dt.Primitive != primitives.String {
+		if right.Primitive != primitives.String {
 			return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
-				"cannot %s %s to %s", tree.currentSymbol().key, right.dt.Primitive, dt))
+				"cannot %s %s to %s", tree.currentSymbol().key, right.Primitive, dt))
 		}
-		result = v.(string) + right.dt.Value.(string)
+		result = v.(string) + right.Value.(string)
 	}
 
-	err = tree.setVar(left.value, result, right.dt.DataType())
+	err = tree.setVar(leftNode.value, result, right.DataType)
 	if err != nil {
 		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
 	}
@@ -155,34 +200,42 @@ func expAssignAdd(tree *ParserT) error {
 	return tree.foldAst(&astNodeT{
 		key: symbols.Calculated,
 		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Null,
-			Value:     nil,
-		},
+		dt:  primitives.NewPrimitive(primitives.Null, nil),
 	})
 }
 
-func expAssignSubtract(tree *ParserT) error {
-	left, right, err := tree.getLeftAndRightSymbols()
+type assFnT func(float64, float64) float64
+
+func _assSub(lv float64, rv float64) float64  { return lv - rv }
+func _assMult(lv float64, rv float64) float64 { return lv * rv }
+func _assDiv(lv float64, rv float64) float64  { return lv / rv }
+
+func expAssignAndOperate(tree *ParserT, operation assFnT) error {
+	leftNode, rightNode, err := tree.getLeftAndRightSymbols()
 	if err != nil {
 		return err
 	}
 
-	convertScalarToBareword(left)
+	convertScalarToBareword(leftNode)
 
-	if left.key != symbols.Bareword {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
+	right, err := rightNode.dt.GetValue()
+	if err != nil {
+		return err
+	}
+
+	if leftNode.key != symbols.Bareword {
+		return raiseError(tree.expression, leftNode, 0, fmt.Sprintf(
 			"left side of %s should be a bareword, instead got %s",
-			tree.currentSymbol().key, left.key))
+			tree.currentSymbol().key, leftNode.key))
 	}
 
-	if right.key != symbols.Number {
-		return raiseError(tree.expression, right, 0, fmt.Sprintf(
+	if rightNode.key != symbols.Number {
+		return raiseError(tree.expression, rightNode, 0, fmt.Sprintf(
 			"right side of %s should not be a %s",
-			tree.currentSymbol().key, right.key))
+			tree.currentSymbol().key, rightNode.key))
 	}
 
-	v, dt, err := tree.getVar(left.value, varAsValue)
+	v, dt, err := tree.getVar(leftNode.value, varAsValue)
 	if err != nil {
 		if !tree.StrictTypes() && strings.Contains(err.Error(), lang.ErrDoesNotExist) {
 			// var doesn't exist and we have strict types disabled so lets create var
@@ -196,17 +249,17 @@ func expAssignSubtract(tree *ParserT) error {
 
 	switch dt {
 	case types.Number, types.Float:
-		f = v.(float64) - right.dt.Value.(float64)
+		f = operation(v.(float64), right.Value.(float64))
 	case types.Integer:
-		f = float64(v.(int)) - right.dt.Value.(float64)
+		f = operation(float64(v.(int)), right.Value.(float64))
 	case types.Null:
-		f = 0 - right.dt.Value.(float64)
+		f = operation(0, right.Value.(float64))
 	default:
 		return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
 			"cannot %s %s", tree.currentSymbol().key, dt))
 	}
 
-	err = tree.setVar(left.value, f, right.dt.DataType())
+	err = tree.setVar(leftNode.value, f, right.DataType)
 	if err != nil {
 		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
 	}
@@ -214,168 +267,49 @@ func expAssignSubtract(tree *ParserT) error {
 	return tree.foldAst(&astNodeT{
 		key: symbols.Calculated,
 		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Null,
-			Value:     nil,
-		},
-	})
-}
-
-func expAssignMultiply(tree *ParserT) error {
-	left, right, err := tree.getLeftAndRightSymbols()
-	if err != nil {
-		return err
-	}
-
-	convertScalarToBareword(left)
-
-	if left.key != symbols.Bareword {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
-			"left side of %s should be a bareword, instead got %s",
-			tree.currentSymbol().key, left.key))
-	}
-
-	if right.key != symbols.Number {
-		return raiseError(tree.expression, right, 0, fmt.Sprintf(
-			"right side of %s should not be a %s",
-			tree.currentSymbol().key, right.key))
-	}
-
-	v, dt, err := tree.getVar(left.value, varAsValue)
-	if err != nil {
-		if !tree.StrictTypes() && strings.Contains(err.Error(), lang.ErrDoesNotExist) {
-			// var doesn't exist and we have strict types disabled so lets create var
-			v, dt, err = float64(0), types.Number, nil
-		} else {
-			return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
-		}
-	}
-
-	var f float64
-
-	switch dt {
-	case types.Number, types.Float:
-		f = v.(float64) * right.dt.Value.(float64)
-	case types.Integer:
-		f = float64(v.(int)) * right.dt.Value.(float64)
-	case types.Null:
-		f = 0
-	default:
-		return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
-			"cannot %s %s", tree.currentSymbol().key, dt))
-	}
-
-	err = tree.setVar(left.value, f, right.dt.DataType())
-	if err != nil {
-		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
-	}
-
-	return tree.foldAst(&astNodeT{
-		key: symbols.Calculated,
-		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Null,
-			Value:     nil,
-		},
-	})
-}
-
-func expAssignDivide(tree *ParserT) error {
-	left, right, err := tree.getLeftAndRightSymbols()
-	if err != nil {
-		return err
-	}
-
-	convertScalarToBareword(left)
-
-	if left.key != symbols.Bareword {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
-			"left side of %s should be a bareword, instead got %s",
-			tree.currentSymbol().key, left.key))
-	}
-
-	if right.key != symbols.Number {
-		return raiseError(tree.expression, right, 0, fmt.Sprintf(
-			"right side of %s should not be a %s",
-			tree.currentSymbol().key, right.key))
-	}
-
-	v, dt, err := tree.getVar(left.value, varAsValue)
-	if err != nil {
-		if !tree.StrictTypes() && strings.Contains(err.Error(), lang.ErrDoesNotExist) {
-			// var doesn't exist and we have strict types disabled so lets create var
-			v, dt, err = float64(0), types.Number, nil
-		} else {
-			return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
-		}
-	}
-
-	var f float64
-
-	switch dt {
-	case types.Number, types.Float:
-		f = v.(float64) / right.dt.Value.(float64)
-	case types.Integer:
-		f = float64(v.(int)) / right.dt.Value.(float64)
-	case types.Null:
-		f = 0 / right.dt.Value.(float64)
-	default:
-		return raiseError(tree.expression, tree.currentSymbol(), 0, fmt.Sprintf(
-			"cannot %s %s", tree.currentSymbol().key, dt))
-	}
-
-	err = tree.setVar(left.value, f, right.dt.DataType())
-	if err != nil {
-		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
-	}
-
-	return tree.foldAst(&astNodeT{
-		key: symbols.Calculated,
-		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Null,
-			Value:     nil,
-		},
+		dt:  primitives.NewPrimitive(primitives.Null, nil),
 	})
 }
 
 func expAssignMerge(tree *ParserT) error {
-	left, right, err := tree.getLeftAndRightSymbols()
+	leftNode, rightNode, err := tree.getLeftAndRightSymbols()
 	if err != nil {
 		return err
 	}
 
-	convertScalarToBareword(left)
-
-	if left.key != symbols.Bareword {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
-			"left side of %s should be a bareword, instead got %s",
-			tree.currentSymbol().key, left.key))
+	right, err := rightNode.dt.GetValue()
+	if err != nil {
+		return err
 	}
 
-	rightVal := right.dt.Value
-	if right.dt.Primitive != primitives.String && reflect.TypeOf(rightVal).Kind() == reflect.String {
-		rightVal, err = lang.UnmarshalDataBuffered(tree.p, []byte(rightVal.(string)), right.dt.MxDT)
+	convertScalarToBareword(leftNode)
+
+	if leftNode.key != symbols.Bareword {
+		return raiseError(tree.expression, leftNode, 0, fmt.Sprintf(
+			"left side of %s should be a bareword, instead got %s",
+			tree.currentSymbol().key, leftNode.key))
+	}
+
+	rightVal := right.Value
+	if right.Primitive != primitives.String && reflect.TypeOf(rightVal).Kind() == reflect.String {
+		rightVal, err = lang.UnmarshalDataBuffered(tree.p, []byte(rightVal.(string)), right.DataType)
 		if err != nil {
 			return err
 		}
 	}
 
-	v, dt, err := tree.getVar(left.value, varAsValue)
+	v, dt, err := tree.getVar(leftNode.value, varAsValue)
 	if err != nil {
 		if !tree.StrictTypes() && strings.Contains(err.Error(), lang.ErrDoesNotExist) {
 			// var doesn't exist and we have strict types disabled so lets create var
-			err = tree.setVar(left.value, rightVal, right.dt.DataType())
+			err = tree.setVar(leftNode.value, rightVal, right.DataType)
 			if err != nil {
 				return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
 			}
 			return tree.foldAst(&astNodeT{
 				key: symbols.Calculated,
 				pos: tree.ast[tree.astPos].pos,
-				dt: &primitives.DataType{
-					Primitive: primitives.Null,
-					Value:     nil,
-				},
+				dt:  primitives.NewPrimitive(primitives.Null, nil),
 			})
 		} else {
 			return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
@@ -384,13 +318,13 @@ func expAssignMerge(tree *ParserT) error {
 
 	merged, err := alter.Merge(tree.p.Context, v, nil, rightVal)
 	if err != nil {
-		return raiseError(tree.expression, left, 0, fmt.Sprintf(
+		return raiseError(tree.expression, leftNode, 0, fmt.Sprintf(
 			"cannot perform merge '%s' into '%s': %s",
-			right.Value(), left.Value(),
+			right.Value, leftNode.Value(),
 			err.Error()))
 	}
 
-	err = tree.setVar(left.value, merged, dt)
+	err = tree.setVar(leftNode.value, merged, dt)
 	if err != nil {
 		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
 	}
@@ -398,9 +332,6 @@ func expAssignMerge(tree *ParserT) error {
 	return tree.foldAst(&astNodeT{
 		key: symbols.Calculated,
 		pos: tree.ast[tree.astPos].pos,
-		dt: &primitives.DataType{
-			Primitive: primitives.Null,
-			Value:     nil,
-		},
+		dt:  primitives.NewPrimitive(primitives.Null, nil),
 	})
 }
