@@ -30,6 +30,9 @@ type document struct {
 	// Description is the contents of the document
 	Description string `yaml:"Description"`
 
+	// Payload is a document describing an APIs payload
+	Payload string `yaml:"Payload"`
+
 	// Flags is a map of supported flags
 	Flags map[string]string `yaml:"Flags"`
 
@@ -53,6 +56,12 @@ type document struct {
 
 	// Date article was published
 	DateTime string `yaml:"DateTime"`
+
+	// WriteTo is the path to write to, if different from the category path
+	WriteTo string `yaml:"WriteTo"`
+
+	// Automatically pulled from file location
+	SourcePath string `yaml:"-"`
 }
 
 // AssociationValues are associations registered by murex data-types
@@ -76,7 +85,11 @@ func (t templates) DocumentFileName(d *document) string {
 
 // DocumentFilePath is the file name and path to write documents to
 func (t templates) DocumentFilePath(d *document) string {
-	return t.OutputPath + t.DocumentFileName(d)
+	path := d.WriteTo
+	if path == "" {
+		path = t.OutputPath
+	}
+	return path + t.DocumentFileName(d)
 }
 
 const dateTimeParse = `2006-01-02 15:04`
@@ -101,6 +114,8 @@ func (t templates) DocumentValues(d *document, docs documents, nest bool) *docum
 		Title:               d.Title,
 		FileName:            t.DocumentFileName(d),
 		FilePath:            t.DocumentFilePath(d),
+		WriteTo:             d.WriteTo,
+		SourcePath:          d.SourcePath,
 		Hierarchy:           d.Hierarchy(),
 		CategoryID:          d.CategoryID,
 		CategoryTitle:       t.ref.Title,
@@ -108,6 +123,7 @@ func (t templates) DocumentValues(d *document, docs documents, nest bool) *docum
 		Summary:             d.Summary,
 		Description:         d.Description,
 		Usage:               d.Usage,
+		Payload:             d.Payload,
 		Examples:            d.Examples,
 		Detail:              d.Detail,
 		Synonyms:            d.Synonyms,
@@ -171,12 +187,15 @@ type documentValues struct {
 	Title               string
 	FileName            string
 	FilePath            string
+	WriteTo             string
+	SourcePath          string
 	Hierarchy           string
 	CategoryID          string
 	CategoryTitle       string
 	CategoryDescription string
 	Summary             string
 	Description         string
+	Payload             string
 	Usage               string
 	Examples            string
 	Flags               sortableFlagValues
