@@ -27,6 +27,8 @@ var safeCmds = []string{
 	"cast",
 	"catch",
 	"count",
+	"config",
+	"autocomplete",
 	"cpuarch",
 	"cpucount",
 	"debug",
@@ -74,8 +76,6 @@ var safeCmds = []string{
 	"rx",
 	"struct-keys",
 	"suffix",
-	"swivel-datatype",
-	"swivel-table",
 	"ta",
 	"tabulate",
 	"time",
